aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xchannels/ixjuser.h4
-rwxr-xr-xcodecs/lpc10/analys.c16
-rwxr-xr-xcodecs/lpc10/bsynz.c16
-rwxr-xr-xcodecs/lpc10/chanwr.c8
-rwxr-xr-xcodecs/lpc10/dcbias.c8
-rwxr-xr-xcodecs/lpc10/decode.c16
-rwxr-xr-xcodecs/lpc10/deemp.c8
-rwxr-xr-xcodecs/lpc10/difmag.c8
-rwxr-xr-xcodecs/lpc10/dyptrk.c12
-rwxr-xr-xcodecs/lpc10/encode.c16
-rwxr-xr-xcodecs/lpc10/energy.c8
-rwxr-xr-xcodecs/lpc10/f2c.h4
-rwxr-xr-xcodecs/lpc10/f2clib.c4
-rwxr-xr-xcodecs/lpc10/ham84.c8
-rwxr-xr-xcodecs/lpc10/hp100.c8
-rwxr-xr-xcodecs/lpc10/invert.c12
-rwxr-xr-xcodecs/lpc10/irc2pc.c12
-rwxr-xr-xcodecs/lpc10/ivfilt.c8
-rwxr-xr-xcodecs/lpc10/lpc10.h4
-rwxr-xr-xcodecs/lpc10/lpcdec.c16
-rwxr-xr-xcodecs/lpc10/lpcenc.c12
-rwxr-xr-xcodecs/lpc10/lpcini.c16
-rwxr-xr-xcodecs/lpc10/lpfilt.c8
-rwxr-xr-xcodecs/lpc10/median.c8
-rwxr-xr-xcodecs/lpc10/mload.c8
-rwxr-xr-xcodecs/lpc10/onset.c12
-rwxr-xr-xcodecs/lpc10/pitsyn.c12
-rwxr-xr-xcodecs/lpc10/placea.c8
-rwxr-xr-xcodecs/lpc10/placev.c8
-rwxr-xr-xcodecs/lpc10/preemp.c8
-rwxr-xr-xcodecs/lpc10/prepro.c8
-rwxr-xr-xcodecs/lpc10/random.c8
-rwxr-xr-xcodecs/lpc10/rcchk.c8
-rwxr-xr-xcodecs/lpc10/synths.c16
-rwxr-xr-xcodecs/lpc10/tbdm.c8
-rwxr-xr-xcodecs/lpc10/voicin.c12
-rwxr-xr-xcodecs/lpc10/vparms.c8
37 files changed, 182 insertions, 182 deletions
diff --git a/channels/ixjuser.h b/channels/ixjuser.h
index 2de8abd1a..949d6964b 100755
--- a/channels/ixjuser.h
+++ b/channels/ixjuser.h
@@ -1,8 +1,8 @@
/******************************************************************************
$Id$
$Log$
-Revision 1.15 1999/12/01 05:25:58 markster
-Version 0.3.0 from FTP
+Revision 1.13 1999/12/01 05:25:58 markster
+Version 0.1.12 from FTP
Revision 1.1 1999/12/01 05:25:58 markster
Start on the Internet Phone Jack channel
diff --git a/codecs/lpc10/f2c.h b/codecs/lpc10/f2c.h
index 594d3706d..b2ff08c8b 100755
--- a/codecs/lpc10/f2c.h
+++ b/codecs/lpc10/f2c.h
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
diff --git a/codecs/lpc10/f2clib.c b/codecs/lpc10/f2clib.c
index 0e7e8dc87..c36bfb7f1 100755
--- a/codecs/lpc10/f2clib.c
+++ b/codecs/lpc10/f2clib.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
diff --git a/codecs/lpc10/lpc10.h b/codecs/lpc10/lpc10.h
index 5804fc57b..6da9dba2a 100755
--- a/codecs/lpc10/lpc10.h
+++ b/codecs/lpc10/lpc10.h
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 00:20:06 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 00:20:06 markster
+Version 0.1.12 from FTP
Revision 1.1 2000/01/05 00:20:06 markster
Add broken lpc10 code... It's not too far from working I don't think...
diff --git a/codecs/lpc10/placea.c b/codecs/lpc10/placea.c
index 3db692cde..99d9df347 100755
--- a/codecs/lpc10/placea.c
+++ b/codecs/lpc10/placea.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2001/04/12 21:27:53 markster
-Version 0.3.0 from FTP
+Revision 1.11 2001/04/12 21:27:53 markster
+Version 0.1.12 from FTP
Revision 1.3 2001/04/12 21:27:53 markh
app_record now supports wildcards of sort so your output file is not overwritten every time it's run. File.h got a documentation update on the ast_fileexists to include the return call. Watch out for the placea.c placev.c code, it's updates have not been tested yet. Just a few parenthesis to make it compile nicer on newer gcc versions with all the -W flags set.
@@ -32,8 +32,8 @@ extern int placea_(integer *ipitch, integer *voibuf, integer *obound, integer *a
/* PLACEA Version 48 */
/* $Log$
- * Revision 1.13 2001/04/12 21:27:53 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2001/04/12 21:27:53 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.3 2001/04/12 21:27:53 markh
/* app_record now supports wildcards of sort so your output file is not overwritten every time it's run. File.h got a documentation update on the ast_fileexists to include the return call. Watch out for the placea.c placev.c code, it's updates have not been tested yet. Just a few parenthesis to make it compile nicer on newer gcc versions with all the -W flags set.
diff --git a/codecs/lpc10/placev.c b/codecs/lpc10/placev.c
index 93dbd6d5a..a3cdce132 100755
--- a/codecs/lpc10/placev.c
+++ b/codecs/lpc10/placev.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2001/04/12 21:27:53 markster
-Version 0.3.0 from FTP
+Revision 1.11 2001/04/12 21:27:53 markster
+Version 0.1.12 from FTP
Revision 1.3 2001/04/12 21:27:53 markh
app_record now supports wildcards of sort so your output file is not overwritten every time it's run. File.h got a documentation update on the ast_fileexists to include the return call. Watch out for the placea.c placev.c code, it's updates have not been tested yet. Just a few parenthesis to make it compile nicer on newer gcc versions with all the -W flags set.
@@ -32,8 +32,8 @@ extern int placev_(integer *osbuf, integer *osptr, integer *oslen, integer *obou
/* PLACEV Version 48 */
/* $Log$
- * Revision 1.13 2001/04/12 21:27:53 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2001/04/12 21:27:53 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.3 2001/04/12 21:27:53 markh
/* app_record now supports wildcards of sort so your output file is not overwritten every time it's run. File.h got a documentation update on the ast_fileexists to include the return call. Watch out for the placea.c placev.c code, it's updates have not been tested yet. Just a few parenthesis to make it compile nicer on newer gcc versions with all the -W flags set.
diff --git a/codecs/lpc10/analys.c b/codecs/lpc10/analys.c
index c90f2c1ec..180c2f027 100755
--- a/codecs/lpc10/analys.c
+++ b/codecs/lpc10/analys.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -79,8 +79,8 @@ static integer c__1 = 1;
/* ANALYS Version 55 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -246,8 +246,8 @@ static integer c__1 = 1;
real phi[100] /* was [10][10] */, psi[10];
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -277,8 +277,8 @@ static integer c__1 = 1;
/* Frame size, Prediction order, Pitch period */
/* Arguments to ANALYS */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -79,8 +79,8 @@ static integer c__1 = 1;
/* ANALYS Version 55 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -246,8 +246,8 @@ static integer c__1 = 1;
real phi[100] /* was [10][10] */, psi[10];
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -277,8 +277,8 @@ static integer c__1 = 1;
/* Arguments to ANALYS */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/bsynz.c b/codecs/lpc10/bsynz.c
index c0dedea1e..99874824e 100755
--- a/codecs/lpc10/bsynz.c
+++ b/codecs/lpc10/bsynz.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
/* BSYNZ Version 54 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -144,8 +144,8 @@ extern struct {
real lpi0, hpi0;
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -175,8 +175,8 @@ extern struct {
/* Frame size, Prediction order, Pitch period */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
/* BSYNZ Version 54 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -144,8 +144,8 @@ extern struct {
real lpi0, hpi0;
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -175,8 +175,8 @@ extern struct {
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/chanwr.c b/codecs/lpc10/chanwr.c
index ebd5631d5..6d232e285 100755
--- a/codecs/lpc10/chanwr.c
+++ b/codecs/lpc10/chanwr.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -35,8 +35,8 @@ extern int chanrd_(integer *order, integer *ipitv, integer *irms, integer *irc,
/* CHANL Version 49 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -35,8 +35,8 @@ extern int chanrd_(integer *order, integer *ipitv, integer *irms, integer *irc,
/* CHANL Version 49 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/dcbias.c b/codecs/lpc10/dcbias.c
index 5aa29e4b0..1a2289610 100755
--- a/codecs/lpc10/dcbias.c
+++ b/codecs/lpc10/dcbias.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int dcbias_(integer *len, real *speech, real *sigout);
/* DCBIAS Version 50 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int dcbias_(integer *len, real *speech, real *sigout);
/* DCBIAS Version 50 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/decode.c b/codecs/lpc10/decode.c
index 51319daff..15deb9897 100755
--- a/codecs/lpc10/decode.c
+++ b/codecs/lpc10/decode.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -53,8 +53,8 @@ static integer c__2 = 2;
/* DECODE Version 54 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -188,8 +188,8 @@ static integer c__2 = 2;
integer ishift, errcnt, lsb;
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -219,8 +219,8 @@ static integer c__2 = 2;
/* Frame size, Prediction order, Pitch period */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -53,8 +53,8 @@ static integer c__2 = 2;
/* DECODE Version 54 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -188,8 +188,8 @@ static integer c__2 = 2;
integer ishift, errcnt, lsb;
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -219,8 +219,8 @@ static integer c__2 = 2;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/deemp.c b/codecs/lpc10/deemp.c
index 52e20886a..a2adb83e1 100755
--- a/codecs/lpc10/deemp.c
+++ b/codecs/lpc10/deemp.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int deemp_(real *x, integer *n, struct lpc10_decoder_state *st);
/* DEEMP Version 48 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int deemp_(real *x, integer *n, struct lpc10_decoder_state *st);
/* DEEMP Version 48 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/difmag.c b/codecs/lpc10/difmag.c
index 918b68c25..8d3591635 100755
--- a/codecs/lpc10/difmag.c
+++ b/codecs/lpc10/difmag.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int difmag_(real *speech, integer *lpita, integer *tau, integer *ltau, in
/* DIFMAG Version 49 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int difmag_(real *speech, integer *lpita, integer *tau, integer *ltau, in
/* DIFMAG Version 49 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/dyptrk.c b/codecs/lpc10/dyptrk.c
index 227c97887..d5a63d065 100755
--- a/codecs/lpc10/dyptrk.c
+++ b/codecs/lpc10/dyptrk.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -47,8 +47,8 @@ extern struct {
/* DYPTRK Version 52 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -136,8 +136,8 @@ extern struct {
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -47,8 +47,8 @@ extern struct {
/* DYPTRK Version 52 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -136,8 +136,8 @@ extern struct {
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/encode.c b/codecs/lpc10/encode.c
index e1733171f..e14ab3969 100755
--- a/codecs/lpc10/encode.c
+++ b/codecs/lpc10/encode.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -43,8 +43,8 @@ static integer c__2 = 2;
/* ENCODE Version 54 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -128,8 +128,8 @@ static integer c__2 = 2;
integer idel, nbit, i__, j, i2, i3, mrk;
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -151,8 +151,8 @@ static integer c__2 = 2;
/* Frame size, Prediction order, Pitch period */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -43,8 +43,8 @@ static integer c__2 = 2;
/* ENCODE Version 54 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -128,8 +128,8 @@ static integer c__2 = 2;
integer idel, nbit, i__, j, i2, i3, mrk;
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -151,8 +151,8 @@ static integer c__2 = 2;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/energy.c b/codecs/lpc10/energy.c
index d5b9700d8..a46e8626e 100755
--- a/codecs/lpc10/energy.c
+++ b/codecs/lpc10/energy.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int energy_(integer *len, real *speech, real *rms);
/* ENERGY Version 50 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int energy_(integer *len, real *speech, real *rms);
/* ENERGY Version 50 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/ham84.c b/codecs/lpc10/ham84.c
index a9665d690..7f618c963 100755
--- a/codecs/lpc10/ham84.c
+++ b/codecs/lpc10/ham84.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ham84_(integer *input, integer *output, integer *errcnt);
/* HAM84 Version 45G */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ham84_(integer *input, integer *output, integer *errcnt);
/* HAM84 Version 45G */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/hp100.c b/codecs/lpc10/hp100.c
index b223d43df..fa829eb08 100755
--- a/codecs/lpc10/hp100.c
+++ b/codecs/lpc10/hp100.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -39,8 +39,8 @@ extern int inithp100_(void);
/* HP100 Version 55 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -39,8 +39,8 @@ extern int inithp100_(void);
/* HP100 Version 55 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/invert.c b/codecs/lpc10/invert.c
index 203c7acde..c5b4368d0 100755
--- a/codecs/lpc10/invert.c
+++ b/codecs/lpc10/invert.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
/* INVERT Version 45G */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -91,8 +91,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
/* INVERT Version 45G */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -91,8 +91,8 @@ extern int invert_(integer *order, real *phi, real *psi, real *rc);
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/irc2pc.c b/codecs/lpc10/irc2pc.c
index 6f0b2d1b5..4b634bcd5 100755
--- a/codecs/lpc10/irc2pc.c
+++ b/codecs/lpc10/irc2pc.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
/* IRC2PC Version 48 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -82,8 +82,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
/* IRC2PC Version 48 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -82,8 +82,8 @@ extern int irc2pc_(real *rc, real *pc, integer *order, real *gprime, real *g2pas
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/ivfilt.c b/codecs/lpc10/ivfilt.c
index 2f559012a..4d1eb68e7 100755
--- a/codecs/lpc10/ivfilt.c
+++ b/codecs/lpc10/ivfilt.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ivfilt_(real *lpbuf, real *ivbuf, integer *len, integer *nsamp, real
/* IVFILT Version 48 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int ivfilt_(real *lpbuf, real *ivbuf, integer *len, integer *nsamp, real
/* IVFILT Version 48 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/lpcdec.c b/codecs/lpc10/lpcdec.c
index ea68c61d6..198eec727 100755
--- a/codecs/lpc10/lpcdec.c
+++ b/codecs/lpc10/lpcdec.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static integer c__10 = 10;
/* ***************************************************************** */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -113,8 +113,8 @@ static integer c__10 = 10;
real rms;
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -147,8 +147,8 @@ static integer c__10 = 10;
/* Frame size, Prediction order, Pitch period */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static integer c__10 = 10;
/* ***************************************************************** */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -113,8 +113,8 @@ static integer c__10 = 10;
real rms;
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -147,8 +147,8 @@ static integer c__10 = 10;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/lpcenc.c b/codecs/lpc10/lpcenc.c
index 680da5b60..86ad6530f 100755
--- a/codecs/lpc10/lpcenc.c
+++ b/codecs/lpc10/lpcenc.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -50,8 +50,8 @@ static integer c__10 = 10;
/* ***************************************************************** */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -109,8 +109,8 @@ static integer c__10 = 10;
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -50,8 +50,8 @@ static integer c__10 = 10;
/* ***************************************************************** */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -109,8 +109,8 @@ static integer c__10 = 10;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/lpcini.c b/codecs/lpc10/lpcini.c
index bd6b01ae7..d37506881 100755
--- a/codecs/lpc10/lpcini.c
+++ b/codecs/lpc10/lpcini.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -45,8 +45,8 @@ struct {
/* ***************************************************************** */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -71,8 +71,8 @@ struct {
{
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -97,8 +97,8 @@ struct {
/* LPC Configuration parameters: */
/* Frame size, Prediction order, Pitch period */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -45,8 +45,8 @@ struct {
/* ***************************************************************** */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -71,8 +71,8 @@ struct {
{
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -97,8 +97,8 @@ struct {
/* Frame size, Prediction order, Pitch period */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/lpfilt.c b/codecs/lpc10/lpfilt.c
index 3f599f542..932a0a0a2 100755
--- a/codecs/lpc10/lpfilt.c
+++ b/codecs/lpc10/lpfilt.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int lpfilt_(real *inbuf, real *lpbuf, integer *len, integer *nsamp);
/* LPFILT Version 55 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int lpfilt_(real *inbuf, real *lpbuf, integer *len, integer *nsamp);
/* LPFILT Version 55 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/median.c b/codecs/lpc10/median.c
index fcd3d7dce..20253c79c 100755
--- a/codecs/lpc10/median.c
+++ b/codecs/lpc10/median.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern integer median_(integer *d1, integer *d2, integer *d3);
/* MEDIAN Version 45G */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern integer median_(integer *d1, integer *d2, integer *d3);
/* MEDIAN Version 45G */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/mload.c b/codecs/lpc10/mload.c
index 63bcf5ca0..d049e4a21 100755
--- a/codecs/lpc10/mload.c
+++ b/codecs/lpc10/mload.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int mload_(integer *order, integer *awins, integer *awinf, real *speech,
/* MLOAD Version 48 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int mload_(integer *order, integer *awins, integer *awinf, real *speech,
/* MLOAD Version 48 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/onset.c b/codecs/lpc10/onset.c
index 8a115f17c..9c6e2baac 100755
--- a/codecs/lpc10/onset.c
+++ b/codecs/lpc10/onset.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -41,8 +41,8 @@ static real c_b2 = 1.f;
/* ONSET Version 49 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -143,8 +143,8 @@ static real c_b2 = 1.f;
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -41,8 +41,8 @@ static real c_b2 = 1.f;
/* ONSET Version 49 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -143,8 +143,8 @@ static real c_b2 = 1.f;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/pitsyn.c b/codecs/lpc10/pitsyn.c
index 52e41ccac..fe865026d 100755
--- a/codecs/lpc10/pitsyn.c
+++ b/codecs/lpc10/pitsyn.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
/* PITSYN Version 53 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -143,8 +143,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
/* PITSYN Version 53 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -143,8 +143,8 @@ extern int pitsyn_(integer *order, integer *voice, integer *pitch, real *rms, re
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/preemp.c b/codecs/lpc10/preemp.c
index f6dec775c..eb1f936ed 100755
--- a/codecs/lpc10/preemp.c
+++ b/codecs/lpc10/preemp.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int preemp_(real *inbuf, real *pebuf, integer *nsamp, real *coef, real *z
/* PREEMP Version 55 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int preemp_(real *inbuf, real *pebuf, integer *nsamp, real *coef, real *z
/* PREEMP Version 55 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/prepro.c b/codecs/lpc10/prepro.c
index 53c14ba91..b9404294b 100755
--- a/codecs/lpc10/prepro.c
+++ b/codecs/lpc10/prepro.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -44,8 +44,8 @@ static integer c__1 = 1;
/* PREPRO Version 48 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -44,8 +44,8 @@ static integer c__1 = 1;
/* PREPRO Version 48 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/random.c b/codecs/lpc10/random.c
index 4bee0e89e..03c3f32a2 100755
--- a/codecs/lpc10/random.c
+++ b/codecs/lpc10/random.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern integer random_(struct lpc10_decoder_state *st);
/* RANDOM Version 49 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -37,8 +37,8 @@ extern integer random_(struct lpc10_decoder_state *st);
/* RANDOM Version 49 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/rcchk.c b/codecs/lpc10/rcchk.c
index 17d3c190d..a1d338654 100755
--- a/codecs/lpc10/rcchk.c
+++ b/codecs/lpc10/rcchk.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int rcchk_(integer *order, real *rc1f, real *rc2f);
/* RCCHK Version 45G */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -29,8 +29,8 @@ extern int rcchk_(integer *order, real *rc1f, real *rc2f);
/* RCCHK Version 45G */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/synths.c b/codecs/lpc10/synths.c
index 4f8efac5b..43f8f0de1 100755
--- a/codecs/lpc10/synths.c
+++ b/codecs/lpc10/synths.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:39 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:39 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:39 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static real c_b2 = .7f;
/* SYNTHS Version 54 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -178,8 +178,8 @@ static real c_b2 = .7f;
real rci[160] /* was [10][16] */;
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -209,8 +209,8 @@ static real c_b2 = .7f;
/* Frame size, Prediction order, Pitch period */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:39 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -58,8 +58,8 @@ static real c_b2 = .7f;
/* SYNTHS Version 54 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -178,8 +178,8 @@ static real c_b2 = .7f;
real rci[160] /* was [10][16] */;
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
@@ -209,8 +209,8 @@ static real c_b2 = .7f;
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:39 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:39 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:39 markster
diff --git a/codecs/lpc10/tbdm.c b/codecs/lpc10/tbdm.c
index d3b49c9e7..149befe83 100755
--- a/codecs/lpc10/tbdm.c
+++ b/codecs/lpc10/tbdm.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:40 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:40 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:40 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -30,8 +30,8 @@ extern int tbdm_(real *speech, integer *lpita, integer *tau, integer *ltau, real
/* TBDM Version 49 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:40 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -30,8 +30,8 @@ extern int tbdm_(real *speech, integer *lpita, integer *tau, integer *ltau, real
/* TBDM Version 49 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:40 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:40 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
diff --git a/codecs/lpc10/voicin.c b/codecs/lpc10/voicin.c
index 2c92aad33..0a0bf89d2 100755
--- a/codecs/lpc10/voicin.c
+++ b/codecs/lpc10/voicin.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:40 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:40 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:40 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
/* VOICIN Version 52 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:40 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -290,8 +290,8 @@ s*/
/* Global Variables: */
/* Arguments */
/* $Log$
* Revision 1.13 2000/01/05 08:20:40 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -48,8 +48,8 @@ extern struct {
/* VOICIN Version 52 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:40 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:40 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
@@ -290,8 +290,8 @@ s*/
/* Arguments */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:40 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:40 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
diff --git a/codecs/lpc10/vparms.c b/codecs/lpc10/vparms.c
index 3bd2d58d2..9341df122 100755
--- a/codecs/lpc10/vparms.c
+++ b/codecs/lpc10/vparms.c
@@ -1,8 +1,8 @@
/*
$Log$
-Revision 1.13 2000/01/05 08:20:40 markster
-Version 0.3.0 from FTP
+Revision 1.11 2000/01/05 08:20:40 markster
+Version 0.1.12 from FTP
Revision 1.2 2000/01/05 08:20:40 markster
Some OSS fixes and a few lpc changes to make it actually work
@@ -33,8 +33,8 @@ static real c_b2 = 1.f;
/* VPARMS Version 50 */
/* $Log$
* Revision 1.13 2000/01/05 08:20:40 markster
* Version 0.3.0 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster
/* Some OSS fixes and a few lpc changes to make it actually work
@@ -33,8 +33,8 @@ static real c_b2 = 1.f;
/* VPARMS Version 50 */
/* $Log$
- * Revision 1.13 2000/01/05 08:20:40 markster
- * Version 0.3.0 from FTP
+ * Revision 1.11 2000/01/05 08:20:40 markster
+ * Version 0.1.12 from FTP
*
/* Revision 1.2 2000/01/05 08:20:40 markster